Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(98)

Unified Diff: tools/get_archive.py

Issue 15755017: Switch from DRT to content shell. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/dom/dom.py ('k') | tools/testing/dart/drt_updater.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/get_archive.py
diff --git a/tools/get_archive.py b/tools/get_archive.py
index e91926725656053c744def96f290269971e969a2..e7ab03d02f535d0f784bcb7da7b0293f40b879c8 100755
--- a/tools/get_archive.py
+++ b/tools/get_archive.py
@@ -4,7 +4,7 @@
# for details. All rights reserved. Use of this source code is governed by a
# BSD-style license that can be found in the LICENSE file.
# Gets or updates a DumpRenderTree (a nearly headless build of chrome). This is
# used for running browser tests of client applications.
import json
@@ -113,7 +113,7 @@ def EnsureConfig():
if not HasBotoConfig():
print >>sys.stderr, '''
*******************************************************************************
* WARNING: Can't download DumpRenderTree! This is required to test client apps.
* You need to do a one-time configuration step to access Google Storage.
* Please run this command and follow the instructions:
* %s config
@@ -347,7 +347,7 @@ def main():
GetSdkRevision('sdk', SDK_DIR, SDK_VERSION, SDK_LATEST_PATTERN,
SDK_PERMANENT, args.revision)
elif positional[0] == 'drt':
- GetDartiumRevision('DumpRenderTree', DRT_DIR, DRT_VERSION,
+ GetDartiumRevision('content_shell', DRT_DIR, DRT_VERSION,
DRT_LATEST_PATTERN, DRT_PERMANENT_PATTERN,
args.revision)
CopyDrtFont(DRT_DIR)
@@ -4,7 +4,7 @@
# for details. All rights reserved. Use of this source code is governed by a
# BSD-style license that can be found in the LICENSE file.
-# Gets or updates a DumpRenderTree (a nearly headless build of chrome). This is
+# Gets or updates a content shell (a nearly headless build of chrome). This is
# used for running browser tests of client applications.
import json
@@ -113,7 +113,7 @@ def EnsureConfig():
print >>sys.stderr, '''
*******************************************************************************
-* WARNING: Can't download DumpRenderTree! This is required to test client apps.
+* WARNING: Can't download content shell! This is required to test client apps.
* You need to do a one-time configuration step to access Google Storage.
* Please run this command and follow the instructions:
« no previous file with comments | « tools/dom/dom.py ('k') | tools/testing/dart/drt_updater.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698